pub struct InstanceUpdate {
pub error: Option<InstanceUpdateError>,
pub instance: Option<String>,
pub status: Option<String>,
}Expand description
Update of a single instance.
This type is not used in any activity, and only used as part of another schema.
Fields
error: Option<InstanceUpdateError>Errors that occurred during the instance update.
instance: Option<String>Fully-qualified URL of the instance being updated.
status: Option<String>Status of the instance update. Possible values are:
- “PENDING”: The instance update is pending execution.
- “ROLLING_FORWARD”: The instance update is going forward.
- “ROLLING_BACK”: The instance update is being rolled back.
- “PAUSED”: The instance update is temporarily paused (inactive).
- “ROLLED_OUT”: The instance update is finished, the instance is running the new template.
- “ROLLED_BACK”: The instance update is finished, the instance has been reverted to the previous template.
- “CANCELLED”: The instance update is paused and no longer can be resumed, undefined in which template the instance is running.