pub struct InstanceUpdateList {
pub items: Option<Vec<InstanceUpdate>>,
pub kind: Option<String>,
pub next_page_token: Option<String>,
pub self_link: Option<String>,
}Expand description
Response returned by ListInstanceUpdates method.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- list instance updates rolling updates (response)
Fields
items: Option<Vec<InstanceUpdate>>Collection of requested instance updates.
kind: Option<String>[Output Only] Type of the resource.
next_page_token: Option<String>A token used to continue a truncated list request.
self_link: Option<String>[Output Only] The fully qualified URL for the resource.