pub struct RollingUpdateMethods<'a, C>where
C: 'a,{ /* private fields */ }Expand description
A builder providing access to all methods supported on rollingUpdate resources.
It is not used directly, but through the Replicapoolupdater hub.
Example
Instantiate a resource builder
extern crate hyper;
extern crate hyper_rustls;
extern crate google_replicapoolupdater1_beta1 as replicapoolupdater1_beta1;
use replicapoolupdater1_beta1::{Replicapoolupdater, FieldMask, hyper_rustls, hyper_util, yup_oauth2};
let secret: yup_oauth2::ApplicationSecret = Default::default();
let connector = hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_only()
.enable_http2()
.build();
let executor = hyper_util::rt::TokioExecutor::new();
let auth = yup_oauth2::InstalledFlowAuthenticator::with_client(
secret,
yup_oauth2::InstalledFlowReturnMethod::HTTPRedirect,
yup_oauth2::client::CustomHyperClientBuilder::from(
hyper_util::client::legacy::Client::builder(executor).build(connector),
),
).build().await.unwrap();
let client = hyper_util::client::legacy::Client::builder(
hyper_util::rt::TokioExecutor::new()
)
.build(
hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_or_http()
.enable_http2()
.build()
);
let mut hub = Replicapoolupdater::new(client, auth);
// Usually you wouldn't bind this to a variable, but keep calling *CallBuilders*
// like `cancel(...)`, `get(...)`, `insert(...)`, `list(...)`, `list_instance_updates(...)`, `pause(...)`, `resume(...)` and `rollback(...)`
// to build up your call.
let rb = hub.rolling_updates();Implementations
Sourceimpl<'a, C> RollingUpdateMethods<'a, C>
impl<'a, C> RollingUpdateMethods<'a, C>
Sourcepub fn cancel(
&self,
project: &str,
zone: &str,
rolling_update: &str,
) -> RollingUpdateCancelCall<'a, C>
pub fn cancel( &self, project: &str, zone: &str, rolling_update: &str, ) -> RollingUpdateCancelCall<'a, C>
Create a builder to help you perform the following task:
Cancels an update. The update must be PAUSED before it can be cancelled. This has no effect if the update is already CANCELLED.
Arguments
project- The Google Developers Console project name.zone- The name of the zone in which the update’s target resides.rollingUpdate- The name of the update.
Sourcepub fn get(
&self,
project: &str,
zone: &str,
rolling_update: &str,
) -> RollingUpdateGetCall<'a, C>
pub fn get( &self, project: &str, zone: &str, rolling_update: &str, ) -> RollingUpdateGetCall<'a, C>
Create a builder to help you perform the following task:
Returns information about an update.
Arguments
project- The Google Developers Console project name.zone- The name of the zone in which the update’s target resides.rollingUpdate- The name of the update.
Sourcepub fn insert(
&self,
request: RollingUpdate,
project: &str,
zone: &str,
) -> RollingUpdateInsertCall<'a, C>
pub fn insert( &self, request: RollingUpdate, project: &str, zone: &str, ) -> RollingUpdateInsertCall<'a, C>
Create a builder to help you perform the following task:
Inserts and starts a new update.
Arguments
request- No description provided.project- The Google Developers Console project name.zone- The name of the zone in which the update’s target resides.
Sourcepub fn list(&self, project: &str, zone: &str) -> RollingUpdateListCall<'a, C>
pub fn list(&self, project: &str, zone: &str) -> RollingUpdateListCall<'a, C>
Create a builder to help you perform the following task:
Lists recent updates for a given managed instance group, in reverse chronological order and paginated format.
Arguments
project- The Google Developers Console project name.zone- The name of the zone in which the update’s target resides.
Sourcepub fn list_instance_updates(
&self,
project: &str,
zone: &str,
rolling_update: &str,
) -> RollingUpdateListInstanceUpdateCall<'a, C>
pub fn list_instance_updates( &self, project: &str, zone: &str, rolling_update: &str, ) -> RollingUpdateListInstanceUpdateCall<'a, C>
Create a builder to help you perform the following task:
Lists the current status for each instance within a given update.
Arguments
project- The Google Developers Console project name.zone- The name of the zone in which the update’s target resides.rollingUpdate- The name of the update.
Sourcepub fn pause(
&self,
project: &str,
zone: &str,
rolling_update: &str,
) -> RollingUpdatePauseCall<'a, C>
pub fn pause( &self, project: &str, zone: &str, rolling_update: &str, ) -> RollingUpdatePauseCall<'a, C>
Create a builder to help you perform the following task:
Pauses the update in state from ROLLING_FORWARD or ROLLING_BACK. Has no effect if invoked when the state of the update is PAUSED.
Arguments
project- The Google Developers Console project name.zone- The name of the zone in which the update’s target resides.rollingUpdate- The name of the update.
Sourcepub fn resume(
&self,
project: &str,
zone: &str,
rolling_update: &str,
) -> RollingUpdateResumeCall<'a, C>
pub fn resume( &self, project: &str, zone: &str, rolling_update: &str, ) -> RollingUpdateResumeCall<'a, C>
Create a builder to help you perform the following task:
Continues an update in PAUSED state. Has no effect if invoked when the state of the update is ROLLED_OUT.
Arguments
project- The Google Developers Console project name.zone- The name of the zone in which the update’s target resides.rollingUpdate- The name of the update.
Sourcepub fn rollback(
&self,
project: &str,
zone: &str,
rolling_update: &str,
) -> RollingUpdateRollbackCall<'a, C>
pub fn rollback( &self, project: &str, zone: &str, rolling_update: &str, ) -> RollingUpdateRollbackCall<'a, C>
Create a builder to help you perform the following task:
Rolls back the update in state from ROLLING_FORWARD or PAUSED. Has no effect if invoked when the state of the update is ROLLED_BACK.
Arguments
project- The Google Developers Console project name.zone- The name of the zone in which the update’s target resides.rollingUpdate- The name of the update.